@@ -24,7 +24,7 @@ SE.Numerical <- function(pars, Theta, theta, dentype, itemloc, PrepList, ESTIMAT
         est <- c(est, lrPars@est)
         shortpars <- longpars[est]
     }
-    hess <- numerical_deriv(BL.LL, shortpars, est=est, longpars=longpars, lrPars=lrPars,
+    hess <- numerical_deriv(shortpars, BL.LL, est=est, longpars=longpars, lrPars=lrPars,
                             pars=pars, ngroups=ngroups, J=J, itemloc=itemloc,
                             Theta=Theta, PrepList=PrepList, dentype=dentype,
                             constrain=constrain,
@@ -34,7 +34,7 @@ SE.Numerical <- function(pars, Theta, theta, dentype, itemloc, PrepList, ESTIMAT
     Hess <- matrix(0, length(longpars), length(longpars))
     Hess[est, est] <- -hess
     Hess <- updateHess(h=Hess, L=Ls$L)
-    info <- Hess[infological, infological]
+    info <- as.matrix(Hess[infological, infological])
     ESTIMATE <- loadESTIMATEinfo(info=info, ESTIMATE=ESTIMATE, constrain=constrain, warn=warn)
     return(ESTIMATE)
 }
@@ -209,6 +209,7 @@ SE.simple <- function(PrepList, ESTIMATE, Theta, constrain, Ls, N, type,
         tmp <- -solve(ESTIMATE$hess)
         info <- solve(tmp %*% (Igrad + Iprior) %*% tmp)
     }
+    info <- as.matrix(info)
     colnames(info) <- rownames(info) <- names(ESTIMATE$correction)
     ESTIMATE <- loadESTIMATEinfo(info=info, ESTIMATE=ESTIMATE, constrain=constrain, warn=warn)
     return(ESTIMATE)
@@ -315,9 +316,10 @@ SE.Oakes <- function(pick, pars, L, constrain, est, shortpars, longpars,
     R[ , r, 2L]
 }
 
-SE.Fisher <- function(PrepList, ESTIMATE, Theta, constrain, Ls, N, CUSTOM.IND, SLOW.IND,
-                      warn, Data, full, omp_threads){
+SE.Fisher <- function(PrepList, ESTIMATE, Theta, constrain, Ls, CUSTOM.IND,
+                      SLOW.IND, warn, Data, full, omp_threads){
     pars <- ESTIMATE$pars
+    Ns <- table(Data$group)
     itemloc <- PrepList[[1L]]$itemloc
     ngroups <- length(pars)
     nitems <- length(pars[[1L]]) - 1L
@@ -347,25 +349,42 @@ SE.Fisher <- function(PrepList, ESTIMATE, Theta, constrain, Ls, N, CUSTOM.IND, S
         PrepList[[g]]$tabdata <- tabdata
         gTheta[[g]] <- Theta
     }
-    info <- 0
-    for(pat in seq_len(nrow(tabdata))){
-        for(g in seq_len(ngroups)){
+    info_list <- vector('list', ngroups)
+    for(g in seq_len(ngroups)){
+        info <- 0
+        # reset
+        for(gg in seq_len(ngroups)){
+            for(i in seq_len(nitems)){
+                tmp <- c(itemloc[i]:(itemloc[i+1L] - 1L))
+                pars[[gg]][[i]]@dat <- pars[[gg]][[i]]@itemtrace <-
+                    matrix(0, nrow(Theta), length(tmp))
+            }
+            pars[[gg]][[nitems + 1L]]@rr <-
+                numeric(length(pars[[gg]][[nitems + 1L]]@rr))
+        }
+        for(pat in seq_len(nrow(tabdata))){
             gtabdata <- PrepList[[g]]$tabdata[pat, , drop=FALSE]
-            rlist <- Estep.mirt(pars=pars[[g]], tabdata=gtabdata, freq=1L, CUSTOM.IND=CUSTOM.IND, full=full,
-                                Theta=Theta, prior=Prior[[g]], itemloc=itemloc, deriv=TRUE, omp_threads=omp_threads)
+            rlist <- Estep.mirt(pars=pars[[g]], tabdata=gtabdata, freq=1L,
+                                CUSTOM.IND=CUSTOM.IND, full=full,
+                                Theta=Theta, prior=Prior[[g]], itemloc=itemloc,
+                                deriv=TRUE, omp_threads=omp_threads)
             for(i in seq_len(nitems)){
                 tmp <- c(itemloc[i]:(itemloc[i+1L] - 1L))
                 pars[[g]][[i]]@dat <- rlist$r1[, tmp]
                 pars[[g]][[i]]@itemtrace <- rlist$itemtrace[, tmp]
             }
             pars[[g]][[nitems + 1L]]@rr <- rowSums(rlist$r1)
+            DX <- .Call('computeDPars', pars, gTheta, matrix(0L, 1L, nitems),
+                        ncol(L), 0L, 0L, 1L, TRUE)$grad
+            info <- info + DX %*% t(DX) * rlist$expected
         }
-        DX <- .Call('computeDPars', pars, gTheta, matrix(0L, 1L, nitems), ncol(L), 0L, 0L, 1L, TRUE)$grad
-        info <- info + DX %*% t(DX) * rlist$expected
+        info_list[[g]] <- Ns[g] * info
     }
-    info <- N * info
-    info <- updateHess(info, L=Ls$L)[ESTIMATE$estindex_unique, ESTIMATE$estindex_unique]
+    info <- Reduce("+", info_list)
+    info <- as.matrix(updateHess(info, L=Ls$L)[ESTIMATE$estindex_unique,
+                                               ESTIMATE$estindex_unique])
     colnames(info) <- rownames(info) <- names(ESTIMATE$correction)
-    ESTIMATE <- loadESTIMATEinfo(info=info, ESTIMATE=ESTIMATE, constrain=constrain, warn=warn)
+    ESTIMATE <- loadESTIMATEinfo(info=info, ESTIMATE=ESTIMATE,
+                                 constrain=constrain, warn=warn)
     return(ESTIMATE)
 }
