@@ -166,6 +166,9 @@ EM.group <- function(pars, constrain, Ls, Data, PrepList, list, Theta, DERIV, so
     hess <- matrix(0)
     Elist <- list()
     startMrate <- ifelse(Moptim == 'L-BFGS-B', 5L, 1L)
+    longpars <- longpars_constrain(longpars=longpars, constrain=constrain,
+                                   nconstrain=nconstrain)
+    pars <- reloadPars(longpars=longpars, pars=pars, ngroups=ngroups, J=J)
     if(list$method == 'BL'){
         start <- proc.time()[3L]
         lower <- LBOUND[est]; upper <- UBOUND[est]
@@ -186,7 +189,8 @@ EM.group <- function(pars, constrain, Ls, Data, PrepList, list, Theta, DERIV, so
                          lower=lower, upper=upper), silent=TRUE)
         cycles <- as.integer(opt$counts[1L])
         longpars[est] <- opt$par
-        longpars <- longpars_constrain(longpars=longpars, constrain=constrain)
+        longpars <- longpars_constrain(longpars=longpars, constrain=constrain,
+                                       nconstrain=nconstrain)
         converge <- opt$convergence == 0
         if(list$SE) hess <- opt$hessian
         tmp <- updatePrior(pars=pars, gTheta=gTheta, MC=MC,
@@ -555,9 +559,10 @@ EM.group <- function(pars, constrain, Ls, Data, PrepList, list, Theta, DERIV, so
                     estindex_unique=estindex_unique, correction=correction, hess=hess, random=list(),
                     Prior=Prior, time=c(Estep=as.numeric(Estep.time), Mstep=as.numeric(Mstep.time)),
                     prior=prior, Priorbetween=Priorbetween, sitems=sitems, collectLL=collectLL,
-                    shortpars=longpars[estpars & !redun_constr], lrPars=lrPars,
+                    shortpars=longpars[estpars & !redun_constr], lrPars=lrPars, EMhistory=na.omit(EMhistory),
                     logPrior=LP, fail_invert_info=FALSE, Etable=Elist$rlist, Theta=gTheta[[1L]])
     }
+    attr(ret$EMhistory, "na.action") <- NULL
     for(g in seq_len(ngroups))
         for(i in seq_len(J))
             ret$pars[[g]][[i]]@dat <- matrix(0)
