@@ -472,16 +472,17 @@ M2 <- function(obj, type="M2*", calcNull = TRUE, na.rm=FALSE, quadpts = NULL, th
         newret$SRMSR <- SRMSR
     }
     if(calcNull){
-        null.mod <- try(computeNullModel(data=obj@Data$data, itemtype=obj@Model$itemtype,
-                                         group=obj@Data$group,
+        null.mod <- try(computeNullModel(data=obj@Data$data, group=obj@Data$group,
                                          key=obj@Internals$key))
         if(is(null.mod, 'try-error'))
             stop('Null model did not converge or is not supported', call.=FALSE)
         null.fit <- M2(null.mod, calcNull=FALSE, type=type, quadpts=2)
-        newret$TLI <- tli(X2=newret$M2, X2.null=null.fit$M2, df=newret$df,
-                          df.null=null.fit$df)
-        newret$CFI <- cfi(X2=newret$M2, X2.null=null.fit$M2, df=newret$df,
-                          df.null=null.fit$df)
+        if(null.fit$M2 > newret$M2){
+            newret$TLI <- tli(X2=newret$M2, X2.null=null.fit$M2, df=newret$df,
+                              df.null=null.fit$df)
+            newret$CFI <- cfi(X2=newret$M2, X2.null=null.fit$M2, df=newret$df,
+                              df.null=null.fit$df)
+        } else warning('Null model chi-squared value smaller than fitted model', call.=FALSE)
     }
     newret <- as.data.frame(newret)
     rownames(newret) <- 'stats'
