@@ -1,17 +1,19 @@
 #' Create a user defined item with correct generic functions
 #'
-#' Initializes the proper S4 class and methods necessary for mirt functions to use in estimation.
-#' To use the defined objects pass to the \code{mirt(..., customItems = list())} command, and
-#' ensure that the classes are properly labeled and unique in the list. Additionally,
-#' the input \code{mirt(..., customItemsData = list())} can also be included to specify additional
-#' item-level information to better recycle custom-item defintions (e.g., for supplying varying
-#' Q-matricies), where the \code{list} input must have the same length as the number of items.
-#' For further examples regarding how this function can be used for
-#' fitting unfolding-type models see Liu and Chalmers (2018).
+#' Initializes the proper S4 class and methods necessary for \code{\link{mirt}}
+#' functions to use in estimation. To use the defined objects pass to the
+#' \code{mirt(..., customItems = list())} command, and
+#' ensure that the classes are properly labeled and unique in the list.
+#' Additionally, the input \code{mirt(..., customItemsData = list())} can
+#' also be included to specify additional item-level information to better
+#' recycle custom-item definitions (e.g., for supplying varying
+#' Q-matrices), where the \code{list} input must have the same length as the
+#' number of items. For further examples regarding how this function can be
+#' used for fitting unfolding-type models see Liu and Chalmers (2018).
 #'
-#' The \code{summary()} function will not return proper standardized loadings since the function
-#' is not sure how to handle them (no slopes could be defined at all!). Instead loadings of .001
-#' are filled in as place-holders.
+#' The \code{summary()} function will not return proper standardized loadings
+#' since the function is not sure how to handle them (no slopes could be
+#' defined at all!). Instead loadings of .001 are filled in as place-holders.
 #'
 #' @aliases createItem
 #' @param name a character indicating the item class name to be defined
@@ -94,7 +96,7 @@
 #'
 #' x <- createItem(name, par=par, est=est, P=P.old2PL)
 #'
-#' #So, let's estimate it!
+#' # So, let's estimate it!
 #' dat <- expand.table(LSAT7)
 #' sv <- mirt(dat, 1, c(rep('2PL',4), 'old2PL'), customItems=list(old2PL=x), pars = 'values')
 #' tail(sv) #looks good
@@ -109,7 +111,7 @@
 #' mod <- mirt(dat, 1, c(rep('2PL',4), 'old2PL'), customItems=list(old2PL=xs))
 #' coef(mod, simplify=TRUE)
 #'
-#' #several secondary functions supported
+#' # several secondary functions supported
 #' M2(mod, calcNull=FALSE)
 #' itemfit(mod)
 #' fscores(mod, full.scores=FALSE)
@@ -136,7 +138,7 @@
 #' mod <- mirt(dat, 1, c(rep('2PL',4), 'old2PL'), customItems=list(old2PL=x))
 #' coef(mod, simplify=TRUE)
 #'
-#' ###non-linear
+#' ### non-linear
 #' name <- 'nonlin'
 #' par <- c(a1 = .5, a2 = .1, d = 0)
 #' est <- c(TRUE, TRUE, TRUE)
@@ -153,7 +155,7 @@
 #' mod <- mirt(dat, 1, c(rep('2PL',4), 'nonlin'), customItems=list(nonlin=x2))
 #' coef(mod)
 #'
-#' ###nominal response model (Bock 1972 version)
+#' ### nominal response model (Bock 1972 version)
 #' Tnom.dev <- function(ncat) {
 #'    T <- matrix(1/ncat, ncat, ncat - 1)
 #'    diag(T[-1, ]) <-  diag(T[-1, ]) - 1
@@ -197,6 +199,7 @@ createItem <- function(name, par, est, P, gr=NULL, hss = NULL, gen = NULL,
     if(bytecompile) P <- compiler::cmpfun(P)
     dps <- dps2 <- function() NULL
     if(derivType == 'symbolic' || derivType.hss == 'symbolic'){
+        browser()
         tmppars <- 1L:length(par)
         names(tmppars) <- rep("par", length(par))
         dps <- Deriv::Deriv(P, tmppars)
